@@ -8,10 +8,24 @@ import traceback
 from abc import ABC, abstractmethod
 from enum import Enum
 from functools import cached_property
-from typing import Any, Dict, Optional, Union
+from typing import Any, Callable, Dict, Generic, List, Optional, Type, TypeVar, Union
+from uuid import uuid4
 
+from opentelemetry import context as context_api
+from opentelemetry import trace
+from opentelemetry.instrumentation.instrumentor import BaseInstrumentor  # type: ignore
+from opentelemetry.sdk.trace import Span, SpanProcessor, TracerProvider
+from opentelemetry.sdk.trace.export import (
+    BatchSpanProcessor,
+    SimpleSpanProcessor,
+    SpanExporter,
+)
+from opentelemetry.trace import Tracer
 from pydantic import BaseModel, Field
 
+from uipath.agent.conversation import UiPathConversationEvent, UiPathConversationMessage
+from uipath.tracing import LlmOpsHttpExporter, TracingManager
+
 from ._logging import LogsInterceptor
 
 logger = logging.getLogger(__name__)
@@ -122,6 +136,17 @@ class UiPathRuntimeResult(BaseModel):
         return result
 
 
+class UiPathConversationHandler(ABC):
+    """Base delegate for handling UiPath conversation events."""
+
+    use_streaming: bool = True
+
+    @abstractmethod
+    def on_event(self, event: UiPathConversationEvent) -> None:
+        """Handle a conversation event for a given execution run."""
+        pass
+
+
 class UiPathTraceContext(BaseModel):
     """Trace context information for tracing and debugging."""
 
@@ -137,13 +162,137 @@ class UiPathTraceContext(BaseModel):
     reference_id: Optional[str] = None
 
 
+class UiPathRuntimeContextBuilder:
+    """Builder class for UiPathRuntimeContext following the builder pattern."""
+
+    def __init__(self):
+        self._kwargs = {}
+
+    def with_defaults(
+        self, config_path: Optional[str] = None, **kwargs
+    ) -> "UiPathRuntimeContextBuilder":
+        """Apply default configuration similar to UiPathRuntimeContext.with_defaults().
+
+        Args:
+            config_path: Path to the configuration file (defaults to UIPATH_CONFIG_PATH env var or "uipath.json")
+            **kwargs: Additional keyword arguments to pass to with_defaults
+
+        Returns:
+            Self for method chaining
+        """
+        from os import environ as env
+
+        resolved_config_path = config_path or env.get(
+            "UIPATH_CONFIG_PATH", "uipath.json"
+        )
+        self._kwargs["config_path"] = resolved_config_path
+
+        self._kwargs.update(
+            {
+                "job_id": env.get("UIPATH_JOB_KEY"),
+                "trace_id": env.get("UIPATH_TRACE_ID"),
+                "tracing_enabled": env.get("UIPATH_TRACING_ENABLED", True),
+                "logs_min_level": env.get("LOG_LEVEL", "INFO"),
+                **kwargs,  # Allow overriding defaults with provided kwargs
+            }
+        )
+
+        self._kwargs["trace_context"] = UiPathTraceContext(
+            trace_id=env.get("UIPATH_TRACE_ID"),
+            parent_span_id=env.get("UIPATH_PARENT_SPAN_ID"),
+            root_span_id=env.get("UIPATH_ROOT_SPAN_ID"),
+            enabled=env.get("UIPATH_TRACING_ENABLED", True),
+            job_id=env.get("UIPATH_JOB_KEY"),
+            org_id=env.get("UIPATH_ORGANIZATION_ID"),
+            tenant_id=env.get("UIPATH_TENANT_ID"),
+            process_key=env.get("UIPATH_PROCESS_UUID"),
+            folder_key=env.get("UIPATH_FOLDER_KEY"),
+            reference_id=env.get("UIPATH_JOB_KEY") or str(uuid4()),
+        )
+
+        return self
+
+    def with_entrypoint(self, entrypoint: str) -> "UiPathRuntimeContextBuilder":
+        """Set the entrypoint for the runtime context.
+
+        Args:
+            entrypoint: The entrypoint to execute
+
+        Returns:
+            Self for method chaining
+        """
+        self._kwargs["entrypoint"] = entrypoint
+        return self
+
+    def with_input(
+        self, input_data: Optional[str] = None, input_file: Optional[str] = None
+    ) -> "UiPathRuntimeContextBuilder":
+        """Set the input data for the runtime context.
+
+        Args:
+            input_data: The input data as a string
+            input_file: Path to the input file
+
+        Returns:
+            Self for method chaining
+        """
+        if input_data is not None:
+            self._kwargs["input"] = input_data
+        if input_file is not None:
+            self._kwargs["input_file"] = input_file
+        return self
+
+    def with_resume(self, enable: bool = True) -> "UiPathRuntimeContextBuilder":
+        """Enable or disable resume mode for the runtime context.
+
+        Args:
+            enable: Whether to enable resume mode (defaults to True)
+
+        Returns:
+            Self for method chaining
+        """
+        self._kwargs["resume"] = enable
+        return self
+
+    def mark_eval_run(self, enable: bool = True) -> "UiPathRuntimeContextBuilder":
+        """Mark this as an evaluation run.
+
+        Args:
+            enable: Whether this is an eval run (defaults to True)
+
+        Returns:
+            Self for method chaining
+        """
+        self._kwargs["is_eval_run"] = enable
+        return self
+
+    def build(self) -> "UiPathRuntimeContext":
+        """Build and return the UiPathRuntimeContext instance.
+
+        Returns:
+            A configured UiPathRuntimeContext instance
+        """
+        config_path = self._kwargs.pop("config_path", None)
+        if config_path:
+            # Create context from config first, then update with any additional kwargs
+            context = UiPathRuntimeContext.from_config(config_path)
+            for key, value in self._kwargs.items():
+                if hasattr(context, key):
+                    setattr(context, key, value)
+            return context
+        else:
+            return UiPathRuntimeContext(**self._kwargs)
+
+
 class UiPathRuntimeContext(BaseModel):
     """Context information passed throughout the runtime execution."""
 
     entrypoint: Optional[str] = None
     input: Optional[str] = None
     input_json: Optional[Any] = None
+    input_message: Optional[UiPathConversationMessage] = None
     job_id: Optional[str] = None
+    execution_id: Optional[str] = None
     trace_id: Optional[str] = None
     trace_context: Optional[UiPathTraceContext] = None
     tracing_enabled: Union[bool, str] = False
@@ -159,6 +308,9 @@ class UiPathRuntimeContext(BaseModel):
     execution_output_file: Optional[str] = None
     input_file: Optional[str] = None
     is_eval_run: bool = False
+    log_handler: Optional[logging.Handler] = None
+    chat_handler: Optional[UiPathConversationHandler] = None
+    is_conversational: Optional[bool] = None
 
     model_config = {"arbitrary_types_allowed": True}
 
@@ -328,6 +480,7 @@ class UiPathBaseRuntime(ABC):
             file=self.context.logs_file,
             job_id=self.context.job_id,
             is_debug_run=self.is_debug_run(),
+            log_handler=self.context.log_handler,
         )
         self.logs_interceptor.setup()
 
@@ -392,8 +545,8 @@ class UiPathBaseRuntime(ABC):
             content = execution_result.to_dict()
             logger.debug(content)
 
-            # Always write output file at runtime
-            if self.context.job_id:
+            # Always write output file at runtime, except evaluation runs
+            if self.context.job_id and not self.context.is_eval_run:
                 with open(self.output_file_path, "w") as f:
                     json.dump(content, f, indent=2, default=str)
 
@@ -465,3 +618,120 @@ class UiPathBaseRuntime(ABC):
             os.makedirs(self.context.runtime_dir, exist_ok=True)
             return os.path.join(self.context.runtime_dir, self.context.state_file)
         return os.path.join("__uipath", "state.db")
+
+
+T = TypeVar("T", bound=UiPathBaseRuntime)
+C = TypeVar("C", bound=UiPathRuntimeContext)
+
+
+class UiPathRuntimeFactory(Generic[T, C]):
+    """Generic factory for UiPath runtime classes."""
+
+    def __init__(self, runtime_class: Type[T], context_class: Type[C]):
+        if not issubclass(runtime_class, UiPathBaseRuntime):
+            raise TypeError(
+                f"runtime_class {runtime_class.__name__} must inherit from UiPathBaseRuntime"
+            )
+
+        if not issubclass(context_class, UiPathRuntimeContext):
+            raise TypeError(
+                f"context_class {context_class.__name__} must inherit from UiPathRuntimeContext"
+            )
+
+        self.runtime_class = runtime_class
+        self.context_class = context_class
+        self.tracer_provider: TracerProvider = TracerProvider()
+        self.tracer_span_processors: List[SpanProcessor] = []
+        trace.set_tracer_provider(self.tracer_provider)
+
+        if os.getenv("UIPATH_JOB_KEY"):
+            self.add_span_exporter(LlmOpsHttpExporter())
+
+    def add_span_exporter(
+        self,
+        span_exporter: SpanExporter,
+        batch: bool = True,
+    ) -> "UiPathRuntimeFactory[T, C]":
+        """Add a span processor to the tracer provider."""
+        span_processor: SpanProcessor
+        if batch:
+            span_processor = UiPathExecutionBatchTraceProcessor(span_exporter)
+        else:
+            span_processor = UiPathExecutionSimpleTraceProcessor(span_exporter)
+        self.tracer_span_processors.append(span_processor)
+        self.tracer_provider.add_span_processor(span_processor)
+        return self
+
+    def add_instrumentor(
+        self,
+        instrumentor_class: Type[BaseInstrumentor],
+        get_current_span_func: Callable[[], Any],
+    ) -> "UiPathRuntimeFactory[T, C]":
+        """Add and instrument immediately."""
+        instrumentor_class().instrument(tracer_provider=self.tracer_provider)
+        TracingManager.register_current_span_provider(get_current_span_func)
+        return self
+
+    def new_context(self, **kwargs) -> C:
+        """Create a new context instance."""
+        return self.context_class(**kwargs)
+
+    def from_context(self, context: C) -> T:
+        """Create runtime instance from context."""
+        return self.runtime_class.from_context(context)
+
+    async def execute(self, context: C) -> Optional[UiPathRuntimeResult]:
+        """Execute runtime with context."""
+        async with self.from_context(context) as runtime:
+            result = await runtime.execute()
+            for span_processor in self.tracer_span_processors:
+                span_processor.force_flush()
+            return result
+
+    async def execute_in_root_span(
+        self, context: C, root_span: str = "root"
+    ) -> Optional[UiPathRuntimeResult]:
+        """Execute runtime with context."""
+        async with self.from_context(context) as runtime:
+            tracer: Tracer = trace.get_tracer("uipath-runtime")
+            with tracer.start_as_current_span(
+                root_span,
+                attributes={"execution.id": context.execution_id}
+                if context.execution_id
+                else {},
+            ):
+                result = await runtime.execute()
+            for span_processor in self.tracer_span_processors:
+                span_processor.force_flush()
+            return result
+
+
+class UiPathExecutionTraceProcessorMixin:
+    def on_start(
+        self, span: Span, parent_context: Optional[context_api.Context] = None
+    ):
+        """Called when a span is started."""
+        if parent_context:
+            parent_span = trace.get_current_span(parent_context)
+        else:
+            parent_span = trace.get_current_span()
+
+        if parent_span and parent_span.is_recording():
+            execution_id = parent_span.attributes.get("execution.id")  # type: ignore[attr-defined]
+            if execution_id:
+                span.set_attribute("execution.id", execution_id)
+            evaluation_id = parent_span.attributes.get("evaluation.id")  # type: ignore[attr-defined]
+            if evaluation_id:
+                span.set_attribute("evaluation.id", evaluation_id)
+
+
+class UiPathExecutionBatchTraceProcessor(
+    UiPathExecutionTraceProcessorMixin, BatchSpanProcessor
+):
+    """Batch span processor that propagates execution.id."""
+
+
+class UiPathExecutionSimpleTraceProcessor(
+    UiPathExecutionTraceProcessorMixin, SimpleSpanProcessor
+):
+    """Simple span processor that propagates execution.id."""
