@@ -3,7 +3,9 @@ from typing import Optional
 from urllib.parse import urlparse
 
 import click
+from dotenv import load_dotenv
 
+from ..._utils.constants import DOTENV_FILE
 from ..spinner import Spinner
 
 
@@ -86,3 +88,23 @@ def get_org_scoped_url(base_url: str) -> str:
     org_name, *_ = parsed.path.strip("/").split("/")
     org_scoped_url = f"{parsed.scheme}://{parsed.netloc}/{org_name}"
     return org_scoped_url
+
+
+def clean_directory(directory: str) -> None:
+    """Clean up Python files in the specified directory.
+
+    Args:
+        directory (str): Path to the directory to clean.
+
+    This function removes all Python files (*.py) from the specified directory.
+    It's used to prepare a directory for a quickstart agent/coded MCP server.
+    """
+    for file_name in os.listdir(directory):
+        file_path = os.path.join(directory, file_name)
+
+        if os.path.isfile(file_path) and file_name.endswith(".py"):
+            os.remove(file_path)
+
+
+def load_environment_variables():
+    load_dotenv(dotenv_path=os.path.join(os.getcwd(), DOTENV_FILE), override=True)
