@@ -74,6 +74,7 @@ class BaseService:
         url: Union[URL, str],
         *,
         scoped: Literal["org", "tenant"] = "tenant",
+        infer_content_type=False,
         **kwargs: Any,
     ) -> Response:
         self._logger.debug(f"Request: {method} {url}")
@@ -105,6 +106,9 @@ class BaseService:
 
         scoped_url = self._url.scope_url(str(url), scoped)
 
+        if infer_content_type:
+            self._client.headers.pop("Content-Type", None)
+
         response = self._client.request(method, scoped_url, **kwargs)
 
         try:
@@ -128,6 +132,7 @@ class BaseService:
         url: Union[URL, str],
         *,
         scoped: Literal["org", "tenant"] = "tenant",
+        infer_content_type=False,
         **kwargs: Any,
     ) -> Response:
         self._logger.debug(f"Request: {method} {url}")
@@ -142,6 +147,9 @@ class BaseService:
 
         scoped_url = self._url.scope_url(str(url), scoped)
 
+        if infer_content_type:
+            self._client_async.headers.pop("Content-Type", None)
+
         response = await self._client_async.request(method, scoped_url, **kwargs)
 
         try:
