@@ -1,7 +1,6 @@
 from os import environ as env
 from typing import Optional
 
-from dotenv import load_dotenv
 from pydantic import ValidationError
 
 from ._config import Config
@@ -29,8 +28,6 @@ from ._utils.constants import (
 )
 from .models.errors import BaseUrlMissingError, SecretMissingError
 
-load_dotenv(override=True)
-
 
 class UiPath:
     def __init__(
@@ -60,6 +57,7 @@ class UiPath:
                     raise SecretMissingError() from e
         self._folders_service: Optional[FolderService] = None
         self._buckets_service: Optional[BucketsService] = None
+        self._attachments_service: Optional[AttachmentsService] = None
 
         setup_logging(debug)
         self._execution_context = ExecutionContext()
@@ -74,11 +72,15 @@ class UiPath:
 
     @property
     def attachments(self) -> AttachmentsService:
-        return AttachmentsService(self._config, self._execution_context)
+        if not self._attachments_service:
+            self._attachments_service = AttachmentsService(
+                self._config, self._execution_context
+            )
+        return self._attachments_service
 
     @property
     def processes(self) -> ProcessesService:
-        return ProcessesService(self._config, self._execution_context)
+        return ProcessesService(self._config, self._execution_context, self.attachments)
 
     @property
     def actions(self) -> ActionsService:
