@@ -18,18 +18,24 @@ class IngestionInProgressException(Exception):
 class EnrichedException(Exception):
     def __init__(self, error: HTTPStatusError) -> None:
         # Extract the relevant details from the HTTPStatusError
-        status_code = error.response.status_code if error.response else "Unknown"
-        url = str(error.request.url) if error.request else "Unknown"
-        response_content = (
+        self.status_code = error.response.status_code if error.response else "Unknown"
+        self.url = str(error.request.url) if error.request else "Unknown"
+        self.http_method = (
+            error.request.method
+            if error.request and error.request.method
+            else "Unknown"
+        )
+        self.response_content = (
             error.response.content.decode("utf-8")
             if error.response and error.response.content
             else "No content"
         )
 
         enriched_message = (
-            f"\nRequest URL: {url}"
-            f"\nStatus Code: {status_code}"
-            f"\nResponse Content: {response_content}"
+            f"\nRequest URL: {self.url}"
+            f"\nHTTP Method: {self.http_method}"
+            f"\nStatus Code: {self.status_code}"
+            f"\nResponse Content: {self.response_content}"
         )
 
         # Initialize the parent Exception class with the formatted message
