@@ -11,36 +11,81 @@ from utils.project_details import ProjectDetails
 from utils.uipath_json import UiPathJson
 
 from tests.cli.utils.common import configure_env_vars
-from uipath._cli.cli_push import push
+from uipath._cli import cli
 
 
-def extract_agent_json_file_from_request(request: Request) -> dict[Any, str]:
-    boundary = re.search(rb"--([a-f0-9]+)", request.content).group(1).decode()
-    parts = request.content.split(f"--{boundary}".encode())
+def extract_agent_json_from_modified_resources(
+    request: Request, *, agent_file_id: str | None = None
+) -> dict[str, Any]:
+    """Extract agent.json content from ModifiedResources in StructuralMigration payload."""
+    match = re.search(
+        rb"boundary=([-._0-9A-Za-z]+)", request.headers.get("Content-Type", "").encode()
+    )
+    if match is None:
+        # Fallback to body sniffing like older helper
+        match = re.search(rb"--([-._0-9A-Za-z]+)", request.content)
+    assert match is not None, "Could not detect multipart boundary"
+    boundary = match.group(1)
+    parts = request.content.split(b"--" + boundary)
 
-    # Locate the agent.json file
-    agent_json_part = None
+    # Require agent_file_id and search only ModifiedResources
+    assert agent_file_id is not None, (
+        "agent_file_id is required to extract agent.json from ModifiedResources"
+    )
+    target_index: str | None = None
     for part in parts:
         if (
-            b'Content-Disposition: form-data; name="file"; filename="agent.json"'
-            in part
+            b"Content-Disposition: form-data;" in part
+            and b"ModifiedResources[" in part
+            and b"].Id" in part
         ):
-            agent_json_part = part
-            break
+            body = part.split(b"\r\n\r\n", 1)
+            if len(body) == 2:
+                value = body[1].strip().strip(b"\r\n")
+                if value.decode(errors="ignore") == agent_file_id:
+                    m = re.search(rb"ModifiedResources\[(\d+)\]\.Id", part)
+                    if m:
+                        target_index = m.group(1).decode()
+                        break
 
-    assert agent_json_part is not None, (
-        "agent.json part not found in the multipart/form-data payload."
+    if target_index is not None:
+        for part in parts:
+            if (
+                b"Content-Disposition: form-data;" in part
+                and f"ModifiedResources[{target_index}].Content".encode() in part
+            ):
+                content_bytes = part.split(b"\r\n\r\n", 1)[1].split(b"\r\n")[0]
+                return json.loads(content_bytes.decode())
+
+    raise AssertionError(
+        "agent.json content not found in ModifiedResources of StructuralMigration payload"
     )
 
-    # Extract the agent.json content
-    agent_json_content = (
-        agent_json_part.split(b"\r\n\r\n", 1)[1].split(b"\r\n--")[0].decode()
+
+def extract_agent_json_from_added_resources(request: Request) -> dict[str, Any]:
+    """Extract agent.json content from AddedResources in StructuralMigration payload."""
+    match = re.search(
+        rb"boundary=([-._0-9A-Za-z]+)", request.headers.get("Content-Type", "").encode()
     )
+    if match is None:
+        match = re.search(rb"--([-._0-9A-Za-z]+)", request.content)
+    assert match is not None, "Could not detect multipart boundary"
+    boundary = match.group(1)
+    parts = request.content.split(b"--" + boundary)
 
-    # Parse the agent.json payload
-    agent_json_data = json.loads(agent_json_content)
+    for part in parts:
+        if (
+            b"Content-Disposition: form-data;" in part
+            and b"AddedResources[" in part
+            and b"].Content" in part
+            and b'filename="agent.json"' in part
+        ):
+            content_bytes = part.split(b"\r\n\r\n", 1)[1].split(b"\r\n")[0]
+            return json.loads(content_bytes.decode())
 
-    return agent_json_data
+    raise AssertionError(
+        "agent.json content not found in AddedResources of StructuralMigration payload"
+    )
 
 
 class TestPush:
@@ -59,7 +104,7 @@ class TestPush:
             os.environ["UIPATH_PROJECT_ID"] = "123"
             with open("pyproject.toml", "w") as f:
                 f.write(project_details.to_toml())
-            result = runner.invoke(push, ["./"])
+            result = runner.invoke(cli, ["push", "./"])
             assert result.exit_code == 1
             assert (
                 "uipath.json not found. Please run `uipath init` in the project directory."
@@ -82,7 +127,7 @@ class TestPush:
             with open("pyproject.toml", "w") as f:
                 f.write(project_details.to_toml())
 
-            result = runner.invoke(push, ["./"])
+            result = runner.invoke(cli, ["push", "./"])
             assert result.exit_code == 1
             assert "UIPATH_PROJECT_ID environment variable not found." in result.output
 
@@ -144,6 +189,14 @@ class TestPush:
                     "isEntryPoint": False,
                     "ignoredFromPublish": False,
                 },
+                {
+                    "id": "898",
+                    "name": "entry-points.json",
+                    "isMain": False,
+                    "fileType": "1",
+                    "isEntryPoint": False,
+                    "ignoredFromPublish": False,
+                },
             ],
             "folderType": "0",
         }
@@ -153,6 +206,8 @@ class TestPush:
             json=mock_structure,
         )
 
+        self._mock_lock_retrieval(httpx_mock, base_url, project_id, times=1)
+
         # Mock agent.json download
         httpx_mock.add_response(
             method="GET",
@@ -161,40 +216,25 @@ class TestPush:
             json={"metadata": {"codeVersion": "0.1.0"}},
         )
 
-        # Mock file upload responses
-        # For main.py
+        # Mock entry-points.json download
         httpx_mock.add_response(
-            method="PUT",
-            url=f"{base_url}/studio_/backend/api/Project/{project_id}/FileOperations/File/123",
+            method="GET",
+            url=f"{base_url}/studio_/backend/api/Project/{project_id}/FileOperations/File/898",
             status_code=200,
+            json={"entryPoints": {}},
         )
 
-        # For pyproject.toml
-        httpx_mock.add_response(
-            method="PUT",
-            url=f"{base_url}/studio_/backend/api/Project/{project_id}/FileOperations/File/456",
-            status_code=200,
-        )
-
-        # For uipath.json
-        httpx_mock.add_response(
-            method="PUT",
-            url=f"{base_url}/studio_/backend/api/Project/{project_id}/FileOperations/File/789",
-            status_code=200,
-        )
-
-        # For uv.lock
         httpx_mock.add_response(
             method="POST",
-            url=f"{base_url}/studio_/backend/api/Project/{project_id}/FileOperations/File",
+            url=f"{base_url}/studio_/backend/api/Project/{project_id}/FileOperations/StructuralMigration",
             status_code=200,
+            json={"success": True},
         )
 
-        # For agent.json
+        # Mock empty folder cleanup - get structure again after migration
         httpx_mock.add_response(
-            method="PUT",
-            url=f"{base_url}/studio_/backend/api/Project/{project_id}/FileOperations/File/246",
-            status_code=200,
+            url=f"{base_url}/studio_/backend/api/Project/{project_id}/FileOperations/Structure",
+            json=mock_structure,
         )
 
         with runner.isolated_filesystem(temp_dir=temp_dir):
@@ -216,24 +256,23 @@ class TestPush:
             os.environ["UIPATH_PROJECT_ID"] = project_id
 
             # Run push
-            result = runner.invoke(push, ["./"])
+            result = runner.invoke(cli, ["push", "./"])
             assert result.exit_code == 0
-            assert "Updated main.py" in result.output
-            assert "Updated pyproject.toml" in result.output
-            assert "Updated uipath.json" in result.output
-            assert "Uploaded uv.lock" in result.output
+            assert "Updating main.py" in result.output
+            assert "Updating pyproject.toml" in result.output
+            assert "Updating uipath.json" in result.output
+            assert "Uploading uv.lock" in result.output
+            assert "Updating agent.json" in result.output
+            assert "Updating entry-points.json" in result.output
 
-            # check incremented code version
-            agent_upload_request = None
-            for request in httpx_mock.get_requests(
-                method="PUT",
-                url=f"{base_url}/studio_/backend/api/Project/{project_id}/FileOperations/File/246",
-            ):
-                agent_upload_request = request
-                break
-
-            agent_json_content = extract_agent_json_file_from_request(
-                agent_upload_request
+            # check incremented code version via StructuralMigration payload
+            structural_migration_request = httpx_mock.get_request(
+                method="POST",
+                url=f"{base_url}/studio_/backend/api/Project/{project_id}/FileOperations/StructuralMigration",
+            )
+            assert structural_migration_request is not None
+            agent_json_content = extract_agent_json_from_modified_resources(
+                structural_migration_request, agent_file_id="246"
             )
 
             # Validate `metadata["codeVersion"]`
@@ -271,6 +310,12 @@ class TestPush:
             method="POST",
             url=f"{base_url}/studio_/backend/api/Project/{project_id}/FileOperations/Folder",
             status_code=200,
+            json={
+                "id": "123",
+                "name": "source_code",
+                "folders": [],
+                "files": [],
+            },
         )
 
         httpx_mock.add_response(
@@ -278,40 +323,19 @@ class TestPush:
             json=mock_structure,
         )
 
-        # Mock file upload responses
-        # For main.py
+        self._mock_lock_retrieval(httpx_mock, base_url, project_id, times=2)
+
         httpx_mock.add_response(
             method="POST",
-            url=f"{base_url}/studio_/backend/api/Project/{project_id}/FileOperations/File",
+            url=f"{base_url}/studio_/backend/api/Project/{project_id}/FileOperations/StructuralMigration",
             status_code=200,
+            json={"success": True},
         )
 
-        # For pyproject.toml
+        # Mock empty folder cleanup - get structure again after migration
         httpx_mock.add_response(
-            method="POST",
-            url=f"{base_url}/studio_/backend/api/Project/{project_id}/FileOperations/File",
-            status_code=200,
-        )
-
-        # For uipath.json
-        httpx_mock.add_response(
-            method="POST",
-            url=f"{base_url}/studio_/backend/api/Project/{project_id}/FileOperations/File",
-            status_code=200,
-        )
-
-        # For uv.lock
-        httpx_mock.add_response(
-            method="POST",
-            url=f"{base_url}/studio_/backend/api/Project/{project_id}/FileOperations/File",
-            status_code=200,
-        )
-
-        # For agent.json
-        httpx_mock.add_response(
-            method="POST",
-            url=f"{base_url}/studio_/backend/api/Project/{project_id}/FileOperations/File",
-            status_code=200,
+            url=f"{base_url}/studio_/backend/api/Project/{project_id}/FileOperations/Structure",
+            json=mock_structure,
         )
 
         with runner.isolated_filesystem(temp_dir=temp_dir):
@@ -333,29 +357,23 @@ class TestPush:
             os.environ["UIPATH_PROJECT_ID"] = project_id
 
             # Run push
-            result = runner.invoke(push, ["./"])
-            print(result.output)
+            result = runner.invoke(cli, ["push", "./"])
             assert result.exit_code == 0
-            assert "Uploaded main.py" in result.output
-            assert "Uploaded pyproject.toml" in result.output
-            assert "Uploaded uipath.json" in result.output
-            assert "Uploaded uv.lock" in result.output
+            assert "Uploading main.py" in result.output
+            assert "Uploading pyproject.toml" in result.output
+            assert "Uploading uipath.json" in result.output
+            assert "Uploading uv.lock" in result.output
+            assert "Uploading agent.json" in result.output
+            assert "Uploading entry-points.json" in result.output
 
             # check expected agent.json fields
-            agent_upload_request = None
-            for request in httpx_mock.get_requests(
+            structural_migration_request = httpx_mock.get_request(
                 method="POST",
-                url=f"{base_url}/studio_/backend/api/Project/{project_id}/FileOperations/File",
-            ):
-                if (
-                    b'Content-Disposition: form-data; name="file"; filename="agent.json"'
-                    in request.content
-                ):
-                    agent_upload_request = request
-                    break
-
-            agent_json_content = extract_agent_json_file_from_request(
-                agent_upload_request
+                url=f"{base_url}/studio_/backend/api/Project/{project_id}/FileOperations/StructuralMigration",
+            )
+            assert structural_migration_request is not None
+            agent_json_content = extract_agent_json_from_added_resources(
+                structural_migration_request
             )
 
             expected_code_version = "1.0.0"
@@ -367,16 +385,13 @@ class TestPush:
             )
             assert "targetRuntime" in agent_json_content["metadata"]
             assert agent_json_content["metadata"]["targetRuntime"] == "python"
-            assert "entryPoints" in agent_json_content
-            assert len(agent_json_content["entryPoints"]) == 2
+            assert "inputSchema" in agent_json_content
+            assert "outputSchema" in agent_json_content
             assert (
-                agent_json_content["entryPoints"][0]["input"]["type"]
+                agent_json_content["inputSchema"]["type"]
                 == uipath_json.entry_points[0].input.type
             )
-            assert (
-                "agent_1_output"
-                in agent_json_content["entryPoints"][0]["output"]["properties"]
-            )
+            assert "agent_1_output" in agent_json_content["outputSchema"]["properties"]
 
     def test_push_with_api_error(
         self,
@@ -411,9 +426,10 @@ class TestPush:
             configure_env_vars(mock_env_vars)
             os.environ["UIPATH_PROJECT_ID"] = project_id
 
-            result = runner.invoke(push, ["./"])
+            result = runner.invoke(cli, ["push", "./"])
             assert result.exit_code == 1
-            assert "Failed to get project structure" in result.output
+            assert "Failed to push UiPath project" in result.output
+            assert "Status Code: 401" in result.output
 
     def test_push_with_nolock_flag(
         self,
@@ -465,33 +481,19 @@ class TestPush:
             json=mock_structure,
         )
 
-        # Mock file upload responses
-        # For main.py
-        httpx_mock.add_response(
-            method="PUT",
-            url=f"{base_url}/studio_/backend/api/Project/{project_id}/FileOperations/File/123",
-            status_code=200,
-        )
+        self._mock_lock_retrieval(httpx_mock, base_url, project_id, times=1)
 
-        # For pyproject.toml
         httpx_mock.add_response(
             method="POST",
-            url=f"{base_url}/studio_/backend/api/Project/{project_id}/FileOperations/File",
+            url=f"{base_url}/studio_/backend/api/Project/{project_id}/FileOperations/StructuralMigration",
             status_code=200,
+            json={"success": True},
         )
 
-        # For agent.json
+        # Mock empty folder cleanup - get structure again after migration
         httpx_mock.add_response(
-            method="POST",
-            url=f"{base_url}/studio_/backend/api/Project/{project_id}/FileOperations/File",
-            status_code=200,
-        )
-
-        # For uipath.json
-        httpx_mock.add_response(
-            method="PUT",
-            url=f"{base_url}/studio_/backend/api/Project/{project_id}/FileOperations/File/789",
-            status_code=200,
+            url=f"{base_url}/studio_/backend/api/Project/{project_id}/FileOperations/Structure",
+            json=mock_structure,
         )
 
         with runner.isolated_filesystem(temp_dir=temp_dir):
@@ -507,15 +509,26 @@ class TestPush:
 
             with open("uv.lock", "w") as f:
                 f.write("")
-            # Set environment variables
+
             configure_env_vars(mock_env_vars)
             os.environ["UIPATH_PROJECT_ID"] = project_id
 
             # Run push with --nolock flag
-            result = runner.invoke(push, ["./", "--nolock"])
+            result = runner.invoke(cli, ["push", "./", "--nolock"])
             assert result.exit_code == 0
-            assert "Updated main.py" in result.output
-            assert "Uploaded pyproject.toml" in result.output
-            assert "Updated uipath.json" in result.output
-            assert "Uploaded agent.json" not in result.output
+            assert "Updating main.py" in result.output
+            assert "Uploading pyproject.toml" in result.output
+            assert "Updating uipath.json" in result.output
             assert "uv.lock" not in result.output
+
+    def _mock_lock_retrieval(
+        self, httpx_mock: HTTPXMock, base_url: str, project_id: str, times: int
+    ):
+        for _ in range(times):
+            httpx_mock.add_response(
+                url=f"{base_url}/studio_/backend/api/Project/{project_id}/Lock",
+                json={
+                    "projectLockKey": "test-lock-key",
+                    "solutionLockKey": "test-solution-lock-key",
+                },
+            )
