@@ -7,7 +7,7 @@ import pytest
 from click.testing import CliRunner
 
 from tests.cli.utils.uipath_json import UiPathJson
-from uipath._cli.cli_run import run  # type: ignore
+from uipath._cli import cli
 from uipath._cli.middlewares import MiddlewareResult
 
 
@@ -56,7 +56,9 @@ class TestRun:
                 file_path = os.path.join(temp_dir, entrypoint)
                 with open(file_path, "w") as f:
                     f.write("script content")
-                result = runner.invoke(run, [entrypoint, "--file", "not-here.json"])
+                result = runner.invoke(
+                    cli, ["run", entrypoint, "--file", "not-here.json"]
+                )
                 assert result.exit_code != 0
                 assert "Error: Invalid value for '-f' / '--file'" in result.output
 
@@ -74,7 +76,9 @@ class TestRun:
                 file_path = os.path.join(temp_dir, file_name)
                 with open(file_path, "w") as f:
                     f.write("file content")
-                result = runner.invoke(run, [script_file_path, "--file", file_path])
+                result = runner.invoke(
+                    cli, ["run", script_file_path, "--file", file_path]
+                )
                 assert result.exit_code == 1
                 assert "Invalid Input File Extension" in result.output
 
@@ -101,7 +105,9 @@ class TestRun:
                         error_message=None,
                         should_include_stacktrace=False,
                     )
-                    result = runner.invoke(run, [entrypoint, "--file", file_path])
+                    result = runner.invoke(
+                        cli, ["run", entrypoint, "--file", file_path]
+                    )
                     assert result.exit_code == 0
                     assert "Successful execution." in result.output
                     assert mock_middleware.call_count == 1
@@ -120,7 +126,7 @@ class TestRun:
     class TestMiddleware:
         def test_no_entrypoint(self, runner: CliRunner, temp_dir: str):
             with runner.isolated_filesystem(temp_dir=temp_dir):
-                result = runner.invoke(run)
+                result = runner.invoke(cli, ["run"])
                 assert result.exit_code == 1
                 assert (
                     "No entrypoint specified. Please provide a path to a Python script."
@@ -131,7 +137,7 @@ class TestRun:
             self, runner: CliRunner, temp_dir: str, entrypoint: str
         ):
             with runner.isolated_filesystem(temp_dir=temp_dir):
-                result = runner.invoke(run, [entrypoint])
+                result = runner.invoke(cli, ["run", entrypoint])
                 assert result.exit_code == 1
                 assert f"Script not found at path {entrypoint}" in result.output
 
@@ -168,8 +174,9 @@ class TestRun:
                 with open("uipath.json", "w") as f:
                     f.write(uipath_json.to_json())
                 result = runner.invoke(
-                    run,
+                    cli,
                     [
+                        "run",
                         script_file_path,
                         "--input-file",
                         input_file_path,
@@ -211,7 +218,7 @@ class TestRun:
             # create uipath.json
             with open("uipath.json", "w") as f:
                 f.write(uipath_json.to_json())
-            result = runner.invoke(run, [script_file_path, "{}"])
+            result = runner.invoke(cli, ["run", script_file_path, "{}"])
             assert result.exit_code == 1
             assert (
                 "No entry function found - No main function (main, run, or execute)"
@@ -252,7 +259,94 @@ class TestRun:
                     error_message="some error message",
                     should_include_stacktrace=True,
                 )
-                result = runner.invoke(run, [script_file_path, "{}"])
+                result = runner.invoke(cli, ["run", script_file_path, "{}"])
             assert result.exit_code == 1
             assert "some error message" in result.output
             assert "Successful execution." not in result.output
+
+    def test_pydantic_model_execution(
+        self,
+        runner: CliRunner,
+        temp_dir: str,
+        entrypoint: str,
+        mock_env_vars: dict,
+        uipath_json: UiPathJson,
+    ):
+        """Test successful execution with Pydantic models."""
+        pydantic_script = """
+from typing import Optional
+from pydantic import BaseModel, Field
+
+
+class PersonIn(BaseModel):
+    name: str
+    age: int
+    email: Optional[str] = None
+
+
+class PersonOut(BaseModel):
+    name: str
+    age: int
+    email: Optional[str] = None
+    is_adult: bool
+    greeting: str
+
+
+def main(input_data: PersonIn) -> PersonOut:
+    return PersonOut(
+        name=input_data.name,
+        age=input_data.age,
+        email=input_data.email,
+        is_adult=input_data.age >= 18,
+        greeting=f"Hello, {input_data.name}!"
+    )
+"""
+
+        input_file_name = "input.json"
+        output_file_name = "output.json"
+        input_json_content = """
+        {
+            "name": "John Doe",
+            "age": 25,
+            "email": "john@example.com"
+        }"""
+
+        with runner.isolated_filesystem(temp_dir=temp_dir):
+            # create input file
+            input_file_path = os.path.join(temp_dir, input_file_name)
+            output_file_path = os.path.join(temp_dir, output_file_name)
+            with open(input_file_path, "w") as f:
+                f.write(input_json_content)
+            # Create test script
+            script_file_path = os.path.join(temp_dir, entrypoint)
+            with open(script_file_path, "w") as f:
+                f.write(pydantic_script)
+            # create uipath.json
+            with open("uipath.json", "w") as f:
+                f.write(uipath_json.to_json())
+
+            result = runner.invoke(
+                cli,
+                [
+                    "run",
+                    script_file_path,
+                    "--input-file",
+                    input_file_path,
+                    "--output-file",
+                    output_file_path,
+                ],
+            )
+
+            assert result.exit_code == 0
+            assert "Successful execution." in result.output
+            assert os.path.exists(output_file_path)
+
+            with open(output_file_path, "r") as f:
+                import json
+
+                output_data = json.load(f)
+                assert output_data["name"] == "John Doe"
+                assert output_data["age"] == 25
+                assert output_data["email"] == "john@example.com"
+                assert output_data["is_adult"] is True
+                assert output_data["greeting"] == "Hello, John Doe!"
